@@ -1,17 +1,13 @@
-use v5.10;
-use warnings;
-
+#! /usr/local/bin/perl -sw
 
 # SHOWCASE VARIOUS ERROR MESSAGES WITH A VERY UNWELL GRAMMAR
 
 use Parse::RecDescent;
 
-open (Parse::RecDescent::ERROR, ">-") or die;
+open (Parse::RecDescent::ERROR, ">errfile") or die;
 
 $grammar =
 q{
-    <warn:3>
-
 	typedef : a ... ...! ... b
 	typedef : a ...!...!...!...! b
 		| /type/ ident /has/ field(s) /end type/
